@@ -7,7 +7,7 @@ use Catmandu::Fix::Has;
 
 with 'Catmandu::Fix::Inlineable';
 
-our $VERSION = '1.21';
+our $VERSION = '1.22';
 
 has path   => (fix_arg => 1);
 has at     => (fix_opt => 1);
@@ -37,16 +37,13 @@ Catmandu::Fix::marc_paste - paste a MARC structured field back into the MARC rec
     marc_paste(fixed001)
 
     # Copy and paste in place (rename a field)
-    do marc_each()
-      if marc_has(001)
-        # Copy a MARC field
-        marc_copy(001, fixed001)
-
+    do marc_each(var:this)
+      if all_match(this.tag,001)
         # Change it
-        set_fieldfixed001.$first.tag,002)
+        set_field(this.tag,002)
 
         # Paste it back into the record
-        marc_paste(fixed001)
+        marc_paste(this)
       end
     end
 
