@@ -15,7 +15,7 @@ memoize('compile_marc_path');
 memoize('parse_marc_spec');
 memoize('_get_index_range');
 
-our $VERSION = '1.21';
+our $VERSION = '1.22';
 
 sub marc_map {
     my $self      = $_[0];
@@ -1167,7 +1167,9 @@ sub marc_paste {
 
     my $value = Catmandu::Util::data_at($json_path,$data);
 
-    return $data unless Catmandu::Util::is_array_ref($value);
+    return $data unless Catmandu::Util::is_array_ref($value) || Catmandu::Util::is_hash_ref($value);
+
+    $value = [$value] unless Catmandu::Util::is_array_ref($value);
 
     my @new_parts;
 
